@@ -5,7 +5,8 @@ from functools import partial
 from contextlib import suppress
 from typing import Dict
 
-from ytmusicapi.auth.headers import prepare_headers
+from requests.structures import CaseInsensitiveDict
+from ytmusicapi.auth.headers import load_headers_file, prepare_headers
 from ytmusicapi.parsers.i18n import Parser
 from ytmusicapi.helpers import *
 from ytmusicapi.mixins.browsing import BrowsingMixin
@@ -15,6 +16,7 @@ from ytmusicapi.mixins.explore import ExploreMixin
 from ytmusicapi.mixins.library import LibraryMixin
 from ytmusicapi.mixins.playlists import PlaylistsMixin
 from ytmusicapi.mixins.uploads import UploadsMixin
+from ytmusicapi.auth.oauth import YTMusicOAuth, is_oauth
 
 
 class YTMusic(BrowsingMixin, SearchMixin, WatchMixin, ExploreMixin, LibraryMixin, PlaylistsMixin,
@@ -68,6 +70,8 @@ class YTMusic(BrowsingMixin, SearchMixin, WatchMixin, ExploreMixin, LibraryMixin
             Available languages can be checked in the FAQ.
         """
         self.auth = auth
+        self.input_dict = None
+        self.is_oauth_auth = False
 
         if isinstance(requests_session, requests.Session):
             self._session = requests_session
@@ -80,8 +84,13 @@ class YTMusic(BrowsingMixin, SearchMixin, WatchMixin, ExploreMixin, LibraryMixin
 
         self.proxies = proxies
         self.cookies = {'CONSENT': 'YES+1'}
+        if self.auth is not None:
+            input_json = load_headers_file(self.auth)
+            self.input_dict = CaseInsensitiveDict(input_json)
+            self.input_dict['filepath'] = self.auth
+            self.is_oauth_auth = is_oauth(self.input_dict)
 
-        self.headers = prepare_headers(self._session, proxies, auth)
+        self.headers = prepare_headers(self._session, proxies, self.input_dict)
 
         if 'x-goog-visitor-id' not in self.headers:
             self.headers.update(get_visitor_id(self._send_get_request))
@@ -121,7 +130,12 @@ class YTMusic(BrowsingMixin, SearchMixin, WatchMixin, ExploreMixin, LibraryMixin
             except KeyError:
                 raise Exception("Your cookie is missing the required value __Secure-3PAPISID")
 
+
+
     def _send_request(self, endpoint: str, body: Dict, additionalParams: str = "") -> Dict:
+
+        if self.is_oauth_auth:
+            self.headers = prepare_headers(self._session, self.proxies, self.input_dict) 
         body.update(self.context)
         params = YTM_PARAMS
         if self.is_browser_auth:
